@@ -10,12 +10,12 @@ from dateutil.tz import tzoffset
 from dateutil.tz import tzutc
 from pythonkc_meetups.types import MeetupEvent
 from pythonkc_meetups.types import MeetupMember
-from pythonkc_meetups.types import MeetupMemberPhoto
+from pythonkc_meetups.types import MeetupPhoto
 from pythonkc_meetups.types import MeetupVenue
 import datetime
 
 
-def parse_event(data, attendees=None):
+def parse_event(data, attendees=None, photos=None):
     """
     Parse a ``MeetupEvent`` from the given response data.
 
@@ -35,8 +35,9 @@ def parse_event(data, attendees=None):
         maybe_rsvp_count=data.get('maybe_rsvp_count', None),
         event_url=data.get('event_url', None),
         photo_url=data.get('photo_url', None),
-        venue=parse_venue(data.get('venue', None)),
-        attendees=attendees
+        venue=parse_venue(data['venue']) if 'venue' in data else None,
+        attendees=attendees,
+        photos=photos
     )
 
 
@@ -46,24 +47,22 @@ def parse_venue(data):
 
     Returns
     -------
-    A `pythonkc_meetups.types.`MeetupVenue`` if non-empty data is given,
-    otherwise ``None``.
+    A `pythonkc_meetups.types.`MeetupVenue``.
 
     """
-    if data:
-        return MeetupVenue(
-            id=data.get('id', None),
-            name=data.get('name', None),
-            address_1=data.get('address_1', None),
-            address_2=data.get('address_2', None),
-            address_3=data.get('address_3', None),
-            city=data.get('city', None),
-            state=data.get('state', None),
-            zip=data.get('zip', None),
-            country=data.get('country', None),
-            lat=data.get('lat', None),
-            lon=data.get('lon', None)
-        )
+    return MeetupVenue(
+        id=data.get('id', None),
+        name=data.get('name', None),
+        address_1=data.get('address_1', None),
+        address_2=data.get('address_2', None),
+        address_3=data.get('address_3', None),
+        city=data.get('city', None),
+        state=data.get('state', None),
+        zip=data.get('zip', None),
+        country=data.get('country', None),
+        lat=data.get('lat', None),
+        lon=data.get('lon', None)
+    )
 
 
 def parse_member_from_rsvp(data):
@@ -78,33 +77,33 @@ def parse_member_from_rsvp(data):
     return MeetupMember(
         id=data['member'].get('member_id', None),
         name=data['member'].get('name', None),
-        photo=parse_member_photo(data.get('member_photo', None))
+        photo=(parse_photo(data['member_photo'])
+               if 'member_photo' in data else None)
     )
 
 
-def parse_member_photo(data):
+def parse_photo(data):
     """
-    Parse a ``MeetupMemberPhoto`` from the given response data.
+    Parse a ``MeetupPhoto`` from the given response data.
 
     Returns
     -------
-    A `pythonkc_meetups.types.`MeetupMemberPhoto`` if non-empty data is given,
-    otherwise ``None``.
+    A `pythonkc_meetups.types.`MeetupPhoto``.
 
     """
-    if data:
-        return MeetupMemberPhoto(
-            id=data.get('id', None),
-            url=data.get('photo_link', None),
-            highres_url=data.get('highres_link', None),
-            thumb_url=data.get('thumb_link', None)
-        )
+    return MeetupPhoto(
+        id=data.get('photo_id', data.get('id', None)),
+        url=data.get('photo_link', None),
+        highres_url=data.get('highres_link', None),
+        thumb_url=data.get('thumb_link', None)
+    )
 
 
 def parse_datetime(utc_timestamp_ms, utc_offset_ms):
     """
     Create a timezone-aware ``datetime.datetime`` from the given UTC timestamp
-    (in milliseconds), if provided. Also, the offset is applied, if given.
+    (in milliseconds), if provided. If an offest it given, it is applied to the
+    datetime returned.
 
     Parameters
     ----------
