@@ -32,6 +32,8 @@ photo_url
     URL of the event photo.
 attendees
     List of ``MeetupMember`` that attended this event if it was in the past.
+photos
+    List of ``MeetupPhoto`` from the event if it was in the past.
 
 MeetupVenue
 -----------
@@ -65,18 +67,18 @@ id
 name
     Full name (first & last) of the member.
 photo
-    A ``MeetupMemberPhoto`` containing URLs to this member's photo resources.
+    A ``MeetupPhoto`` containing URLs to this member's photo resources.
 
-MeetupMemberPhoto
------------------
+MeetupPhoto
+-----------
 id
-    Meetup.com ID for the member photo.
+    Meetup.com ID for the photo.
 url
-    URL of the member photo resource.
+    URL of the photo resource.
 highres_url
-    URL of the high-resolution version of the member photo.
+    URL of the high-resolution version of the photo.
 thumb_url
-    URL of the thumbnail version of the member photo.
+    URL of the thumbnail version of the photo.
 
 """
 
@@ -87,7 +89,7 @@ from collections import namedtuple
 MeetupEvent = namedtuple('MeetupEvent',
         ['id', 'name', 'description', 'time', 'status', 'venue',
          'yes_rsvp_count', 'maybe_rsvp_count', 'event_url', 'photo_url',
-         'attendees'])
+         'attendees', 'photos'])
 
 MeetupVenue = namedtuple('MeetupVenue',
         ['id', 'name', 'address_1', 'address_2', 'address_3', 'city', 'state',
@@ -95,5 +97,5 @@ MeetupVenue = namedtuple('MeetupVenue',
 
 MeetupMember = namedtuple('MeetupMember', ['id', 'name', 'photo'])
 
-MeetupMemberPhoto = namedtuple('MeetupMemberPhoto', 
+MeetupPhoto = namedtuple('MeetupPhoto', 
         ['id', 'url', 'highres_url', 'thumb_url'])
